aboutsummaryrefslogtreecommitdiffstats
path: root/libbe/bug.py
diff options
context:
space:
mode:
authorW. Trevor King <wking@drexel.edu>2008-11-27 11:34:44 -0500
committerW. Trevor King <wking@drexel.edu>2008-11-27 11:34:44 -0500
commit7a67efb3bc61ec499c9af7de7c54a7b98db7eafd (patch)
tree828f1cd2321ef013afa7d408f40d6fef0cab3b62 /libbe/bug.py
parent7603adce0d52e387b8d0e14d881c1a7749a5f9e5 (diff)
downloadbugseverywhere-7a67efb3bc61ec499c9af7de7c54a7b98db7eafd.tar.gz
Added becommands/comment completion.
Diffstat (limited to 'libbe/bug.py')
-rw-r--r--libbe/bug.py9
1 files changed, 8 insertions, 1 deletions
diff --git a/libbe/bug.py b/libbe/bug.py
index 67051f2..f47bcba 100644
--- a/libbe/bug.py
+++ b/libbe/bug.py
@@ -183,7 +183,7 @@ class Bug(object):
if self._comments_loaded == False:
self.load_comments()
# take advantage of the string_thread(auto_name_map=True)
# SIDE-EFFECT of sorting by bug time.
comout = self.comment_root.string_thread(flatten=False,
auto_name_map=True,
bug_shortname=shortname)
@@ -272,6 +272,13 @@ class Bug(object):
def comment_from_uuid(self, uuid):
return self.comment_root.comment_from_uuid(uuid)
+ def comment_shortnames(self, shortname=None):
+ """
+ SIDE-EFFECT : Comment.comment_shortnames will sort the comment
+ tree by comment.time
+ """
+ for id, comment in self.comment_root.comment_shortnames(shortname):
+ yield (id, comment)
# the general rule for bug sorting is that "more important" bugs are
# less than "less important" bugs. This way sorting a list of bugs
@@ -183,7 +183,7 @@ class Bug(object):
self.load_comments()
# take advantage of the string_thread(auto_name_map=True)
- # SIDE-EFFECT of sorting by bug time.
+ # SIDE-EFFECT of sorting by comment time.
comout = self.comment_root.string_thread(flatten=False,
auto_name_map=True,